Stan Math Library: stan/math/rev/scal/fun/Phi.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Phi.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_PHI_HPP
2 #define STAN_MATH_REV_SCAL_FUN_PHI_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/Phi.hpp>
6
7 namespace stan {
8 namespace math {
9
10 namespace {
11 class Phi_vari : public op_v_vari {
12 public:
13 explicit Phi_vari(vari* avi) :
14 op_v_vari(stan::math::Phi(avi->val_), avi) {
15 }
16 void chain() {
17 static const double NEG_HALF = -0.5;
18 avi_->adj_ += adj_
19 * stan::math::INV_SQRT_TWO_PI
20 * std::exp(NEG_HALF * avi_->val_ * avi_->val_);
21 }
22 };
23 }
24
66 inline var Phi(const stan::math::var& a) {
67 return var(new Phi_vari(a.vi_));
68 }
69
70 }
71 }
72 #endif
stan::math::INV_SQRT_TWO_PI
const double INV_SQRT_TWO_PI
Definition: constants.hpp:166
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
stan::math::Phi
fvar< T > Phi(const fvar< T > &x)
Definition: Phi.hpp:14
Phi.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.